==> webkit2gtk_2.44.2.orig.tar.xz: webkitgtk-2.44.2/Source/WebCore/platform/PlatformStrategies.cpp <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "PlatformStrategies.h"

namespace WebCore {

static PlatformStrategies* s_platformStrategies;

bool hasPlatformStrategies()
{
    return !!s_platformStrategies;
}

PlatformStrategies* platformStrategies()
{
    ASSERT(s_platformStrategies);
    
    return s_platformStrategies;
}

void setPlatformStrategies(PlatformStrategies* platformStrategies)
{
    if (!s_platformStrategies) {
        s_platformStrategies = platformStrategies;
        return;
    }
    
    // FIXME: This happens when mixing different platform strategies, and we should probably
    // throw an exception here in release builds.
    ASSERT(platformStrategies == s_platformStrategies);
}

} // namespace WebCore

==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/platform/PlatformStrategies.cpp <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "PlatformStrategies.h"

#include "BlobRegistry.h"
#include "LoaderStrategy.h"
#include "MediaStrategy.h"
#include "PasteboardStrategy.h"

#if ENABLE(DECLARATIVE_WEB_PUSH)
#include "PushStrategy.h"
#endif

namespace WebCore {

static PlatformStrategies* s_platformStrategies;

PlatformStrategies::PlatformStrategies() = default;

PlatformStrategies::~PlatformStrategies() = default;

bool hasPlatformStrategies()
{
    return !!s_platformStrategies;
}

PlatformStrategies* platformStrategies()
{
    ASSERT(s_platformStrategies);
    
    return s_platformStrategies;
}

void setPlatformStrategies(PlatformStrategies* platformStrategies)
{
    if (!s_platformStrategies) {
        s_platformStrategies = platformStrategies;
        return;
    }
    
    // FIXME: This happens when mixing different platform strategies, and we should probably
    // throw an exception here in release builds.
    ASSERT(platformStrategies == s_platformStrategies);
}

CheckedPtr<LoaderStrategy> PlatformStrategies::loaderStrategy()
{
    if (!m_loaderStrategy)
        m_loaderStrategy = createLoaderStrategy();
    return m_loaderStrategy;
}

CheckedPtr<PasteboardStrategy> PlatformStrategies::pasteboardStrategy()
{
    if (!m_pasteboardStrategy)
        m_pasteboardStrategy = createPasteboardStrategy();
    return m_pasteboardStrategy;
}

CheckedRef<MediaStrategy> PlatformStrategies::mediaStrategy()
{
    std::call_once(m_onceKeyForMediaStrategies, [&] {
        m_mediaStrategy = createMediaStrategy();
    });
    return *m_mediaStrategy;
}

CheckedPtr<BlobRegistry> PlatformStrategies::blobRegistry()
{
    if (!m_blobRegistry)
        m_blobRegistry = createBlobRegistry();
    return m_blobRegistry;
}

#if ENABLE(DECLARATIVE_WEB_PUSH)
CheckedPtr<PushStrategy> PlatformStrategies::pushStrategy()
{
    if (!m_pushStrategy)
        m_pushStrategy = createPushStrategy();
    return m_pushStrategy;
}
#endif

} // namespace WebCore
